@@ -4,7 +4,7 @@
  * Copyright (c) 2000 Alexander Neundorf <alexander.neundorf@rz.tu-ilmenau.de>
  *
  * Requires the Qt widget libraries, available at no cost at
- * http://www.troll.no/
+ * https://www.qt.io/
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -188,10 +188,8 @@ void StatisticsView::calculate() {
 				}
 
 				calcCount++;
-				QString number(QLatin1String(""));
-				number.sprintf("%6d", calcCount);
-				QString hits(QLatin1String(""));
-				hits.sprintf("%7d", tmpStr->count);
+				const QString number = QString::asprintf("%6d", calcCount);
+				const QString hits = QString::asprintf("%7d", tmpStr->count);
 				QTreeWidgetItem *item = new QTreeWidgetItem(viewStatistics);
 				item->setText(0, number);
 				item->setText(1, eventCb->currentText());
@@ -218,10 +216,8 @@ void StatisticsView::calculate() {
 					count++;
 			}
 		}
-		QString number(QLatin1String(""));
-		number.sprintf("%6d", calcCount);
-		QString hits(QLatin1String(""));
-		hits.sprintf("%7d", count);
+                const QString number = QString::asprintf("%6d", calcCount);
+                const QString hits = QString::asprintf("%7d", count);
 		QTreeWidgetItem *item = new QTreeWidgetItem(viewStatistics);
 		item->setText(0, number);
 		item->setText(1, eventCb->currentText());
